@@ -14,7 +14,7 @@
 namespace miic {
 namespace structure {
 
-namespace structure_impl {
+namespace detail {
 
 using std::string;
 using std::vector;
@@ -27,14 +27,14 @@ struct Environment {
   vector<vector<double>> data_double;
   // data_numeric_idx[i] = index of i'th smallest value in data_double
   vector<vector<int>> data_numeric_idx;
-  int* oneLineMatrix;
 
   vector<int> is_continuous;
   vector<int> levels;
+  vector<int> has_na;
   int n_eff;
-  vector<Node> nodes{};
-  Edge** edges;
-  bool orientation_phase;
+  vector<Node> nodes;
+  Grid2d<Edge> edges;
+  bool orientation;
   double ori_proba_ratio = 1;
   bool propagation;
   // Level of consistency required for the graph
@@ -56,25 +56,18 @@ struct Environment {
   bool test_mar;
   // Complexity mode. 0: mdl 1: nml
   int cplx{1};
-  // If firstStepIteration is done
-  bool first_iter_done{false};
   // List of ids of edge whose status is not yet determined
   vector<EdgeID> unsettled_list;
   // List of ids of edge whose status is sure to be connected
   vector<EdgeID> connected_list;
-  int numSearchMore{0};
-  int numNoMore{0};
 
   int n_shuffles;
   double conf_threshold;
 
-  int** iterative_cuts;
+  Grid2d<int> iterative_cuts;
   vector<double> sample_weights;
   bool flag_sample_weights;
-  double* noise_vec;
-
-  MemorySpace m;
-  MemorySpace* memoryThreads;
+  vector<double> noise_vec;
 
   double log_eta = 0;
   bool is_k23;
@@ -82,16 +75,9 @@ struct Environment {
   bool no_init_eta{false};
   int half_v_structure;
 
-  // Set the probability threshold for the rank if the contribution probability
-  // is the min value
-  int thresPc{0};
-
   int maxbins;
   int initbins;
 
-  std::map<CacheInfoKey, double> look_scores;
-  std::map<CacheInfoKey, CacheScoreValue> look_scores_orientation;
-
   ExecutionTime exec_time;
   int n_threads;
   CompCache cache;
@@ -100,18 +86,11 @@ struct Environment {
   Environment(const Rcpp::List&, const Rcpp::List&);
   Environment() = default;
 
-  ~Environment() {
-    delete[] oneLineMatrix;
-    for (int i = 0; i < n_nodes; i++) delete[] edges[i];
-    delete[] edges;
-    delete[] noise_vec;
-  }
-
   void readBlackbox(const vector<vector<int>>&);
 };
 
-}  // namespace structure_impl
-using structure_impl::Environment;
+}  // namespace detail
+using detail::Environment;
 }  // namespace structure
 }  // namespace miic
 
